@@ -91,6 +91,8 @@ class CLI(object):  # pylint: disable=too-many-instance-attributes
         self.output = self.output_cls(cli_ctx=self)
         self.result = None
         self.query = query_cls(cli_ctx=self)
+        self.only_show_errors = self.config.get('core', 'only_show_errors', fallback=False)
+        self.enable_color = not self.config.get('core', 'no_color', fallback=False)
 
     @staticmethod
     def _should_show_version(args):
@@ -187,6 +189,13 @@ class CLI(object):  # pylint: disable=too-many-instance-attributes
             raise TypeError('args should be a list or tuple.')
         exit_code = 0
         try:
+            if self.enable_color:
+                import colorama
+                colorama.init()
+                if self.out_file == sys.__stdout__:
+                    # point out_file to the new sys.stdout which is overwritten by colorama
+                    self.out_file = sys.stdout
+
             args = self.completion.get_completion_args() or args
             out_file = out_file or self.out_file
 
@@ -210,14 +219,20 @@ class CLI(object):  # pylint: disable=too-many-instance-attributes
                 if cmd_result and cmd_result.result is not None:
                     formatter = self.output.get_formatter(output_type)
                     self.output.out(cmd_result, formatter=formatter, out_file=out_file)
-            self.raise_event(EVENT_CLI_POST_EXECUTE)
         except KeyboardInterrupt as ex:
-            self.result = CommandResultItem(None, error=ex)
             exit_code = 1
+            self.result = CommandResultItem(None, error=ex, exit_code=exit_code)
         except Exception as ex:  # pylint: disable=broad-except
             exit_code = self.exception_handler(ex)
-            self.result = CommandResultItem(None, error=ex)
+            self.result = CommandResultItem(None, error=ex, exit_code=exit_code)
+        except SystemExit as ex:
+            exit_code = ex.code
+            self.result = CommandResultItem(None, error=ex, exit_code=exit_code)
+            raise ex
         finally:
-            pass
-        self.result.exit_code = exit_code
+            self.raise_event(EVENT_CLI_POST_EXECUTE)
+
+            if self.enable_color:
+                colorama.deinit()
+
         return exit_code
