@@ -8,6 +8,7 @@ from __future__ import print_function
 import errno
 import json
 import traceback
+import sys
 from collections import OrderedDict
 from six import StringIO, text_type, u, string_types
 
@@ -45,6 +46,24 @@ def format_json_color(obj):
     return highlight(format_json(obj), lexers.JsonLexer(), formatters.TerminalFormatter())  # pylint: disable=no-member
 
 
+def format_yaml(obj):
+    import yaml
+    try:
+        return yaml.safe_dump(obj.result, default_flow_style=False, allow_unicode=True)
+    except yaml.representer.RepresenterError:
+        # yaml.safe_dump fails when obj.result is an OrderedDict. knack's --query implementation converts the result to an OrderedDict. https://github.com/microsoft/knack/blob/af674bfea793ff42ae31a381a21478bae4b71d7f/knack/query.py#L46. # pylint: disable=line-too-long
+        return yaml.safe_dump(json.loads(json.dumps(obj.result)), default_flow_style=False, allow_unicode=True)
+
+
+def format_yaml_color(obj):
+    from pygments import highlight, lexers, formatters
+    return highlight(format_yaml(obj), lexers.YamlLexer(), formatters.TerminalFormatter())  # pylint: disable=no-member
+
+
+def format_none(_):
+    return ""
+
+
 def format_table(obj):
     result = obj.result
     try:
@@ -78,8 +97,11 @@ class OutputProducer(object):
     _FORMAT_DICT = {
         'json': format_json,
         'jsonc': format_json_color,
+        'yaml': format_yaml,
+        'yamlc': format_yaml_color,
         'table': format_table,
         'tsv': format_tsv,
+        'none': format_none,
     }
 
     @staticmethod
@@ -124,11 +146,6 @@ class OutputProducer(object):
         if not isinstance(obj, CommandResultItem):
             raise TypeError('Expected {} got {}'.format(CommandResultItem.__name__, type(obj)))
 
-        import platform
-        import colorama
-
-        if platform.system() == 'Windows':
-            out_file = colorama.AnsiToWin32(out_file).stream
         output = formatter(obj)
         try:
             print(output, file=out_file, end='')
@@ -138,10 +155,17 @@ class OutputProducer(object):
             else:
                 raise
         except UnicodeEncodeError:
+            logger.warning("Unable to encode the output with %s encoding. Unsupported characters are discarded.",
+                           out_file.encoding)
             print(output.encode('ascii', 'ignore').decode('utf-8', 'ignore'),
                   file=out_file, end='')
 
     def get_formatter(self, format_type):  # pylint: disable=no-self-use
+        # remove color if stdout is not a tty
+        if not sys.stdout.isatty() and format_type == 'jsonc':
+            return OutputProducer._FORMAT_DICT['json']
+        if not sys.stdout.isatty() and format_type == 'yamlc':
+            return OutputProducer._FORMAT_DICT['yaml']
         return OutputProducer._FORMAT_DICT[format_type]
 
 
